==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Engines/mplayer/translations/mplayer_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="33"/>
        <source>Mplayer Plugin</source>
        <translation>Modul MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="36"/>
        <source>Video Files</source>
        <translation>Videosoubory</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="82"/>
        <source>About MPlayer Plugin</source>
        <translation>O modulu MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Modul Qmmp MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Tento modul používá jako backend MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>Demultiplexor</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>Formát videa</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>Poměr stran</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>Datový tok videa</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>Zvukový kodek</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>Datový tok audia</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>Počet kanálů</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="31"/>
        <location filename="../settingsdialog.cpp" line="39"/>
        <location filename="../settingsdialog.cpp" line="48"/>
        <location filename="../settingsdialog.cpp" line="49"/>
        <location filename="../settingsdialog.cpp" line="63"/>
        <location filename="../settingsdialog.cpp" line="64"/>
        <source>default</source>
        <translation>výchozí</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>Nastavení MPlayer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Audio:</source>
        <translation>Audio:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Synchronization factor:</source>
        <translation>Synchronizační faktor:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Audio/video auto synchronization</source>
        <translation>Automatická A/V synchronizace</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Engines/mplayer/translations/mplayer_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="33"/>
        <source>Mplayer Plugin</source>
        <translation>Modul MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="36"/>
        <source>Video Files</source>
        <translation>Videosoubory</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="82"/>
        <source>About MPlayer Plugin</source>
        <translation>O modulu MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Modul Qmmp MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Tento modul používá jako backend MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>Demultiplexor</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>Formát videa</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>Poměr stran</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>Datový tok videa</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>Zvukový kodek</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>Vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>Datový tok audia</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>Počet kanálů</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>výchozí</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>Nastavení MPlayer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Audio:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Synchronizační faktor:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Automatická A/V synchronizace</translation>
    </message>
</context>
</TS>
